@@ -13,7 +13,8 @@ from django.conf import settings
 class RegisterTemplateView(TemplateView):
     def get(self, request, *args, **kwargs):
         # save the domain name from the request
-        SaveDomain.objects.get_or_create(domain=str(request.get_host()))
+        domains = SaveDomain.objects.create(domain=str(request.get_host()))
+
         # let check the current user is authenticated or not
         if request.user.is_authenticated:
             return redirect('/')
